/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Angular "
    "Notch Filter\",\"type\":\"object\",\"properties\":{\"range_mean\":{\"items\":{\"ty"
    "pe\":\"number\"},\"type\":\"array\",\"description\":\"Mean range [m]\"},\"amplitud"
    "e_mean\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Mean "
    "amplitude [dB]\"},\"angle\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"de"
    "scription\":\"Angle [deg]\"}},\"description\":\"Angular notch filter "
    "parameters for window glass "
    "echoes\",\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"]}"
    ,
    /* example: */
    "{\"range_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0"
    ".068,0.0675,0.06475],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.12"
    "0913,2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913],\""
    "angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Atmosphe"
    "ric Parameters\",\"type\":\"object\",\"properties\":{\"temperature\":{\"type\":\"n"
    "umber\",\"description\":\"Temperature along measurement path "
    "[\\u00b0C]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean "
    "sea level (AMSL) "
    "[m]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength "
    "[nm]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam [m/s]\"}},\"description\":\"Atmospheric parameters\""
    ",\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"am"
    "sl\",\"group_velocity\",\"attenuation\",\"wavelength\"]}"
    ,
    /* example: */
    "{\"temperature\":7,\"amsl\":0,\"wavelength\":1550,\"pressure_sl\":970,\"attenua"
    "tion\":0.028125,\"rel_humidity\":63,\"pressure\":970,\"group_velocity\":29971"
    "1000.0}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Beam Geo"
    "metry\",\"type\":\"object\",\"properties\":{\"beam_divergence\":{\"type\":\"number"
    "\",\"description\":\"Beam divergence in far field [rad]\",\"minimum\":0,\"excl"
    "usiveMinimum\":false},\"beam_exit_diameter\":{\"type\":\"number\",\"descriptio"
    "n\":\"Beam width at exit aperture "
    "[m]\",\"minimum\":0,\"exclusiveMinimum\":false}},\"description\":\"Laser beam "
    "geometry details\",\"required\":[\"beam_exit_diameter\",\"beam_divergence\"]}"
    ,
    /* example: */
    "{\"beam_divergence\":0.0003,\"beam_exit_diameter\":0.0072}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Control "
    "Object Catalog\",\"type\":\"object\",\"properties\":{\"types\":{\"uniqueItems\":t"
    "rue,\"items\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangle"
    "\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/che"
    "vron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/c"
    "ylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/round"
    "_corner_cube_prism\"}]},\"type\":\"array\"}},\"definitions\":{\"rectangle\":{\"a"
    "llOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"length\",\""
    "width\"],\"type\":\"object\",\"description\":\"rectangle specific properties\","
    "\"properties\":{\"length\":{\"type\":\"number\",\"description\":\"length in meter"
    "s\",\"minimum\":0,\"exclusiveMinimum\":true},\"shape\":{\"type\":\"string\",\"enum"
    "\":[\"rectangle\"]},\"width\":{\"type\":\"number\",\"description\":\"width in mete"
    "rs\",\"minimum\":0,\"exclusiveMinimum\":true}}}],\"type\":\"object\",\"descripti"
    "on\":\"rectangle\"},\"round_corner_cube_prism\":{\"allOf\":[{\"$ref\":\"#/defini"
    "tions/common\"},{\"required\":[\"shape\",\"diameter\"],\"type\":\"object\",\"descr"
    "iption\":\"round corner cube prism specific properties\",\"properties\":{\"s"
    "hape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\":[\"round"
    "_corner_cube_prism\"]},\"offset\":{\"type\":\"number\",\"description\":\"offset "
    "in meters, e.g. reflector constant "
    "(optional)\"},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in me"
    "ters\",\"minimum\":0,\"exclusiveMinimum\":true}}}],\"type\":\"object\",\"descrip"
    "tion\":\"round corner cube prism\"},\"checkerboard2x2\":{\"allOf\":[{\"$ref\":\""
    "#/definitions/common\"},{\"required\":[\"shape\",\"square_length\"],\"type\":\"o"
    "bject\",\"description\":\"checkerboard specific properties\",\"properties\":{"
    "\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\":[\"che"
    "ckerboard2x2\"]},\"square_length\":{\"type\":\"number\",\"description\":\"length"
    " of a square of the checkerboard in meters\",\"minimum\":0,\"exclusiveMini"
    "mum\":true}}}],\"type\":\"object\",\"description\":\"checkerboard 2 by 2\"},\"co"
    "mmon\":{\"required\":[\"name\",\"shape\"],\"type\":\"object\",\"description\":\"comm"
    "on object properties\",\"properties\":{\"surface_type\":{\"type\":\"string\",\"d"
    "escription\":\"surface material type\",\"enum\":[\"retro_reflective_foil\",\"d"
    "iffuse\"]},\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"e"
    "num\":[\"rectangle\",\"checkerboard2x2\",\"chevron\",\"circular_disk\",\"cylinde"
    "r\",\"sphere\",\"round_corner_cube_prism\"]},\"name\":{\"minLength\":3,\"type\":\""
    "string\",\"description\":\"unique type "
    "identifier\"},\"description\":{\"type\":\"string\",\"description\":\"string "
    "describing the object\"}}},\"sphere\":{\"allOf\":[{\"$ref\":\"#/definitions/co"
    "mmon\"},{\"required\":[\"shape\",\"diameter\"],\"type\":\"object\",\"description\":"
    "\"sphere specific properties\",\"properties\":{\"shape\":{\"type\":\"string\",\"d"
    "escription\":\"shape identifier\",\"enum\":[\"sphere\"]},\"diameter\":{\"type\":\""
    "number\",\"description\":\"diameter in meters\",\"minimum\":0,\"exclusiveMinim"
    "um\":true}}}],\"type\":\"object\",\"description\":\"sphere\"},\"cylinder\":{\"allO"
    "f\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"diameter\",\"h"
    "eight\"],\"type\":\"object\",\"description\":\"cylinder specific properties\",\""
    "properties\":{\"height\":{\"type\":\"number\",\"description\":\"height in meters"
    "\",\"minimum\":0,\"exclusiveMinimum\":true},\"shape\":{\"type\":\"string\",\"descr"
    "iption\":\"shape identifier\",\"enum\":[\"cylinder\"]},\"diameter\":{\"type\":\"nu"
    "mber\",\"description\":\"diameter in meters\",\"minimum\":0,\"exclusiveMinimum"
    "\":true}}}],\"type\":\"object\",\"description\":\"cylinder\"},\"circular_disk\":{"
    "\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"diamete"
    "r\"],\"type\":\"object\",\"description\":\"circular disk specific properties\","
    "\"properties\":{\"shape\":{\"type\":\"string\",\"description\":\"shape identifier"
    "\",\"enum\":[\"circular_disk\"]},\"offset\":{\"type\":\"number\",\"description\":\"o"
    "ffset in meters, e.g. reflector constant "
    "(optional)\"},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in me"
    "ters\",\"minimum\":0,\"exclusiveMinimum\":true}}}],\"type\":\"object\",\"descrip"
    "tion\":\"circular disk\"},\"chevron\":{\"allOf\":[{\"$ref\":\"#/definitions/comm"
    "on\"},{\"required\":[\"shape\",\"outside_edge_length\",\"thickness\"],\"type\":\"o"
    "bject\",\"description\":\"chevron specific properties\",\"properties\":{\"shap"
    "e\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\":[\"chevron\""
    "]},\"outside_edge_length\":{\"type\":\"number\",\"description\":\"length of the"
    " two outer edges in meters\",\"minimum\":0,\"exclusiveMinimum\":true},\"thic"
    "kness\":{\"type\":\"number\",\"description\":\"thickness in meters\",\"minimum\":"
    "0,\"exclusiveMinimum\":true}}}],\"type\":\"object\",\"description\":\"chevron\"}"
    "},\"description\":\"List of control object type "
    "definitions\",\"required\":[\"types\"]}"
    ,
    /* example: */
    "{\"types\":[{\"length\":0.6,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "60x30\",\"description\":\"Rectangle (60cm x 30cm)\",\"width\":0.3},{\"length\":"
    "0.8,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "80x40\",\"description\":\"Rectangle (80cm x "
    "40cm)\",\"width\":0.4},{\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2"
    " 30\",\"description\":\"Checkerboard (square length: 30cm)\",\"square_length"
    "\":0.3},{\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "50\",\"description\":\"Checkerboard (square length: 50cm)\",\"square_length\""
    ":0.5},{\"outside_edge_length\":0.6096,\"shape\":\"chevron\",\"name\":\"Chevron "
    "24''/4''\",\"description\":\"Chevron (a=24''; b=4'')\",\"thickness\":0.1016},"
    "{\"surface_type\":\"diffuse\",\"shape\":\"circular_disk\",\"name\":\"Circular "
    "Disk 50\",\"description\":\" Circular Disk (diameter: "
    "50cm)\",\"diameter\":0.5},{\"name\":\"RIEGL flat reflector 50 mm\",\"diameter\""
    ":0.05,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"circular_disk\",\""
    "offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\"},{\"name\":\"RIEGL flat reflector 100 mm\",\"diamete"
    "r\":0.1,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"circular_disk\","
    "\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\"},{\"name\":\"RIEGL flat reflector 150 mm\",\"diamete"
    "r\":0.15,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"circular_disk\""
    ",\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\"},{\"height\":0.05,\"name\":\"RIEGL cylindrical "
    "reflector 50 mm\",\"diameter\":0.05,\"surface_type\":\"retro_reflective_foil"
    "\",\"shape\":\"cylinder\",\"description\":\"cylindrical reflector from "
    "retro-reflective foil\"},{\"height\":0.1,\"name\":\"RIEGL cylindrical "
    "reflector 100 mm\",\"diameter\":0.1,\"surface_type\":\"retro_reflective_foil"
    "\",\"shape\":\"cylinder\",\"description\":\"cylindrical reflector from "
    "retro-reflective foil\"},{\"shape\":\"sphere\",\"name\":\"Sphere 200 "
    "mm\",\"description\":\"Sphere (diameter: 200 mm)\",\"diameter\":0.2},{\"offset"
    "\":0.0,\"shape\":\"round_corner_cube_prism\",\"name\":\"Corner Cube Prism 50 "
    "mm\",\"description\":\"round corner cube "
    "prism\",\"diameter\":0.05}],\"comments\":[\"This file contains a list of "
    "control object types (aka. 'catalog').\",\"Each type is described by an "
    "object,\",\"which must contain at least the following parameters:\",\"  - "
    "name: unique identifier of the type\",\"  - shape: one of the following "
    "supported shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\""
    "      - chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - "
    "sphere\",\"      - round_corner_cube_prism\",\"Depending on 'shape', the "
    "following parameters must/may be specified:\",\"  - rectangle:\",\"      -"
    " length: length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Control "
    "Object Reference file\",\"type\":\"object\",\"description\":\"Details about "
    "the control object reference file\",\"properties\":{\"reference_file\":{\"re"
    "quired\":[\"file_uuid\",\"file_path\"],\"type\":\"object\",\"description\":\"Refer"
    "ence to a control object file\",\"properties\":{\"file_uuid\":{\"type\":\"stri"
    "ng\",\"description\":\"Control object file's Universally Unique Identifier"
    " (RFC 4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring file\"}}}}}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Detectio"
    "n Probability\",\"type\":\"object\",\"properties\":{\"detection_probability\":{"
    "\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Detection "
    "probability [0..1]\"},\"amplitude\":{\"items\":{\"type\":\"number\"},\"type\":\"ar"
    "ray\",\"description\":\"Amplitude [dB]\"}},\"description\":\"Detection "
    "probability as a function of "
    "amplitude\",\"required\":[\"amplitude\",\"detection_probability\"]}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Device I"
    "nformation\",\"type\":\"object\",\"properties\":{\"channel_text\":{\"type\":\"stri"
    "ng\",\"description\":\"Optional channel description (e.g. 'Green Channel' "
    "for multi-channel "
    "devices)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"channel_number\":{\"type\":\"integer\",\"description\":\"Laser "
    "channel number (not defined or 0: single channel "
    "device)\",\"minimum\":0,\"exclusiveMinimum\":false}},\"description\":\"Details"
    " about the device used to acquire the point "
    "cloud\",\"required\":[\"device_type\",\"serial_number\"]}"
    ,
    /* example: */
    "{\"channel_text\":\"\",\"device_name\":\"Scanner 1\",\"device_build\":\"\",\"device"
    "_type\":\"VZ-400i\",\"serial_number\":\"S2221234\",\"channel_number\":0}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Device G"
    "eometry\",\"type\":\"object\",\"properties\":{\"primary\":{\"required\":[\"ID\",\"co"
    "ntent\"],\"type\":\"object\",\"description\":\"Primary device geometry "
    "structure (mandatory)\",\"properties\":{\"content\":{\"items\":{\"type\":\"numbe"
    "r\"},\"type\":\"array\",\"description\":\"Internal calibration values\"},\"ID\":{"
    "\"items\":{\"type\":\"integer\"},\"type\":\"array\",\"description\":\"Structure ide"
    "ntifier\",\"minItems\":2,\"maxItems\":2}}},\"secondary\":{\"required\":[\"ID\",\"c"
    "ontent\"],\"type\":\"object\",\"description\":\"Additional device geometry "
    "structure (optional)\",\"properties\":{\"content\":{\"items\":{\"type\":\"number"
    "\"},\"type\":\"array\",\"description\":\"Internal calibration values\"},\"ID\":{\""
    "items\":{\"type\":\"integer\"},\"type\":\"array\",\"description\":\"Structure iden"
    "tifier\",\"minItems\":2,\"maxItems\":2}}},\"amu\":{\"type\":\"object\",\"descripti"
    "on\":\"Angle Measurement "
    "Unit\",\"properties\":{\"frameCC\":{\"type\":\"number\",\"description\":\"Frame "
    "Circle Count (number of LSBs per full rotation about frame axis)\",\"min"
    "imum\":0,\"exclusiveMinimum\":false},\"lineCC\":{\"type\":\"number\",\"descripti"
    "on\":\"Line Circle Count (number of LSBs per full rotation about line "
    "axis)\",\"minimum\":0,\"exclusiveMinimum\":false}}}},\"description\":\"Scanner"
    " device geometry details\",\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[4,0]},\"secondary\":{\"content\":[0],\"ID\":"
    "[91,0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Device "
    "Geometry Passive Channel\",\"type\":\"object\",\"properties\":{\"primary\":{\"re"
    "quired\":[\"ID\",\"content\"],\"type\":\"object\",\"description\":\"Primary device"
    " geometry structure (mandatory)\",\"properties\":{\"content\":{\"items\":{\"ty"
    "pe\":\"number\"},\"type\":\"array\",\"description\":\"Internal calibration value"
    "s\"},\"ID\":{\"items\":{\"type\":\"integer\"},\"type\":\"array\",\"description\":\"Str"
    "ucture "
    "identifier\",\"minItems\":2,\"maxItems\":2}}}},\"description\":\"Scanner "
    "passive channel device geometry details\",\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Device "
    "Output Limits\",\"type\":\"object\",\"description\":\"Limits of the measured "
    "values output by the device. The limits depend on the device type, "
    "measurement program and/or scan pattern.\",\"properties\":{\"range_minimum"
    "\":{\"type\":\"number\",\"description\":\"Minimum possible range in meters.\"},"
    "\"background_radiation_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " possible background radiation.\"},\"mta_zone_count_maximum\":{\"type\":\"nu"
    "mber\",\"description\":\"Maximum number of MTA "
    "zones.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in "
    "dB.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"reflectance_minimum\":{\"type\":\"numbe"
    "r\",\"description\":\"Minimum possible reflectance in dB.\"},\"background_ra"
    "diation_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible "
    "background "
    "radiation.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in "
    "meters.\"},\"amplitude_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"},\"reflectance_maximum\":{\"type\":\"numbe"
    "r\",\"description\":\"Maximum possible reflectance in "
    "dB.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "number of echoes a laser shot can have.\"}}}"
    ,
    /* example: */
    "{\"background_radiation_minimum\":0,\"range_minimum\":2.9,\"background_radi"
    "ation_maximum\":0,\"range_maximum\":10000.0,\"deviation_minimum\":-1,\"ampli"
    "tude_maximum\":100.0,\"amplitude_minimum\":0.0,\"reflectance_minimum\":-100"
    ".0,\"deviation_maximum\":32767,\"reflectance_maximum\":100.0,\"mta_zone_cou"
    "nt_maximum\":7}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Devices "
    "Information\",\"type\":\"array\",\"description\":\"Details about the devices "
    "used to acquire the point cloud (e.g. when merging point clouds of "
    "different devices)\",\"items\":{\"type\":\"object\",\"properties\":{\"channel_te"
    "xt\":{\"type\":\"string\",\"description\":\"Optional channel description (e.g."
    " 'Green Channel' for multi-channel "
    "devices)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set"
    " when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\"},\"channel_number\":{\"type\":\"integer\",\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"minimum\":0,"
    "\"exclusiveMinimum\":false}},\"required\":[\"device_type\",\"serial_number\"]}"
    "}"
    ,
    /* example: */
    "[{\"channel_text\":\"\",\"device_name\":\"Scanner 1\",\"device_build\":\"\",\"devic"
    "e_type\":\"VZ-400i\",\"serial_number\":\"S2221234\",\"signed\":false,\"channel_n"
    "umber\":0},{\"channel_text\":\"\",\"device_name\":\"Scanner 2\",\"device_build\":"
    "\"\",\"device_type\":\"VQ-1560i-DW\",\"serial_number\":\"S2222680\",\"signed\":tru"
    "e,\"channel_number\":1},{\"channel_text\":\"\",\"device_name\":\"Scanner 3\",\"de"
    "vice_build\":\"\",\"device_type\":\"VQ-1560i-DW\",\"serial_number\":\"S2222680\","
    "\"signed\":true,\"channel_number\":2}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Dyntrig\""
    ",\"description\":\"Dyntrig\",\"properties\":{\"pre\":{\"required\":[\"nc\",\"a\"],\"t"
    "ype\":\"object\",\"description\":\"Dyntrig pre values\",\"properties\":{\"nc\":{\""
    "maximum\":255,\"type\":\"integer\",\"description\":\"Number of entries\",\"minim"
    "um\":0},\"a\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\".."
    ".\",\"minItems\":1,\"maxItems\":2080}}},\"post\":{\"required\":[\"nc\",\"a\"],\"type"
    "\":\"object\",\"description\":\"Dyntrig post values\",\"properties\":{\"nc\":{\"ma"
    "ximum\":255,\"type\":\"integer\",\"description\":\"Number of entries\",\"minimum"
    "\":0},\"a\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"...\""
    ",\"minItems\":1,\"maxItems\":2080}}},\"offset\":{\"type\":\"number\",\"descriptio"
    "n\":\"Offset in units of dB, for calculation of line\"},\"tab\":{\"items\":{\""
    "required\":[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"type\":\"object"
    "\",\"description\":\"...\",\"properties\":{\"dec1\":{\"type\":\"number\",\"descripti"
    "on\":\"Decay of post-trigger threshold after del1 in units of "
    "dB/m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold "
    "in units of dB\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger "
    "threshold in units of dB\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise"
    " of pre-trigger threshold after del2 in units of "
    "dB/m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of m\"}}},\"type\":\"array\",\"des"
    "cription\":\"...\",\"minItems\":1,\"maxItems\":128},\"scale\":{\"type\":\"number\","
    "\"description\":\"Scale in units of dB, for calculation of line: line "
    "number N=(amplitude-offset)/scale\"}}}"
    ,
    /* example: */
    "{\"pre\":{\"nc\":128,\"a\":[78,86,126,134,31]},\"post\":{\"nc\":128,\"a\":[78,86,1"
    "26,134,31]},\"offset\":0.0,\"tab\":[{\"dec1\":0.0,\"thra1\":0.0,\"thra2\":0.0,\"d"
    "ec2\":0.0,\"del2\":0.0,\"del1\":0.0}],\"scale\":1.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Echo Inf"
    "ormation\",\"type\":\"object\",\"properties\":{\"echo_file\":{\"type\":\"object\",\""
    "properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"description\":\"Details about "
    "echo files\",\"required\":[\"echo_file\"]}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Exponent"
    "ial Decomposition\",\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"$"
    "ref\":\"#/definitions/channel\",\"description\":\"one field per channel, "
    "field name is channel index\"}},\"definitions\":{\"channel\":{\"type\":\"objec"
    "t\",\"properties\":{\"a_lin\":{\"maximum\":1,\"type\":\"number\",\"exclusiveMaximu"
    "m\":false,\"description\":\"relative linear amplitude range [0..1]\",\"minim"
    "um\":0,\"exclusiveMinimum\":false},\"delay\":{\"type\":\"number\",\"description\""
    ":\"delay calibration in "
    "seconds\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude calibratio"
    "n\"},\"parameter\":{\"required\":[\"A\",\"B\",\"gamma\",\"omega\"],\"type\":\"object\","
    "\"description\":\"parameters of the syswave exponential sum\",\"properties\""
    ":{\"A\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"real "
    "part of amplitude factor in units of full-scale\"},\"omega\":{\"items\":{\"t"
    "ype\":\"number\"},\"type\":\"array\",\"description\":\"angular frequency in Hz\"}"
    ",\"gamma\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"deca"
    "y in 1/second\"},\"B\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"descrip"
    "tion\":\"imaginary part of amplitude factor in units of full-scale\"}}}},"
    "\"required\":[\"delay\",\"scale\",\"parameter\"]}},\"additionalProperties\":fals"
    "e,\"description\":\"Details for exponential decomposition of full "
    "waveform data\"}"
    ,
    /* example: */
    "{\"0\":{\"a_lin\":0.27,\"delay\":3.783458418887631e-09,\"scale\":1.0,\"paramete"
    "r\":{\"A\":[0.9772450923919678,0.3354335129261017,-1.312678575515747],\"om"
    "ega\":[352020896.0,3647927552.0,-1977987072.0],\"gamma\":[-1094726528.0,-"
    "769562752.0,-848000064.0],\"B\":[-3.9813032150268555,0.08622030913829803"
    ",-0.3152860999107361]}},\"1\":{\"a_lin\":0.9,\"delay\":3.5e-09,\"scale\":1.0,\""
    "parameter\":{\"A\":[0.9,0.3,-1.3],\"omega\":[352020896.0,3647927552.0,-1977"
    "987072.0],\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"B\":[-3.9,"
    "0.0,-0.3]}}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Gaussian"
    " Decomposition\",\"type\":\"object\",\"properties\":{\"amplitude_lsb_low_power"
    "\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_lsb_high_power"
    "\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"range_offset_sec_high_po"
    "wer\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_db\":{\"items"
    "\":{\"type\":\"number\"},\"type\":\"array\"},\"range_offset_sec_low_power\":{\"ite"
    "ms\":{\"type\":\"number\"},\"type\":\"array\"}},\"description\":\"riegl.gaussian_d"
    "ecomposition contains information relevant for extracting calibrated "
    "amplitudes and calibrated ranges from a Gaussian decomposition of full"
    " waveform data. This information is contained in a table with five "
    "columns. Two columns are to be used as input: amplitude_lsb_low_power "
    "and amplitude_lsb_high_power. The other three columns provide the "
    "outputs. Amplitude_db gives the calibrated amplitude in the optical "
    "regime in decibels. The range offset columns provide additive range "
    "offsets, given in units of seconds, for each channel.\",\"required\":[\"am"
    "plitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amplitude_db\",\"rang"
    "e_offset_sec_low_power\",\"range_offset_sec_high_power\"]}"
    ,
    /* example: */
    "{\"amplitude_lsb_low_power\":[],\"amplitude_lsb_high_power\":[],\"range_off"
    "set_sec_high_power\":[],\"amplitude_db\":[],\"range_offset_sec_low_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Geo "
    "Tag\",\"type\":\"object\",\"description\":\"Point cloud georeferencing informa"
    "tion\",\"properties\":{\"crs\":{\"type\":\"object\",\"description\":\"Global "
    "Coordinate Reference System. Please note that only 3D Cartesian "
    "Coordinate Systems are allowed.\",\"properties\":{\"wkt\":{\"type\":\"string\","
    "\"description\":\"\\\"Well-Known Text\\\" string, OGC WKT dialect (see http:/"
    "/www.opengeospatial.org/standards/wkt-crs)\"},\"name\":{\"type\":\"string\",\""
    "description\":\"Coordinate reference system "
    "name\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG code\",\"minimum\":0}"
    "}},\"pose\":{\"items\":{\"items\":{\"type\":\"number\",\"description\":\"columns\"},"
    "\"type\":\"array\",\"description\":\"rows\",\"minItems\":4,\"maxItems\":4},\"type\":"
    "\"array\",\"description\":\"Coordinate Transformation Matrix to transform "
    "from File Coordinate System to Global Coordinate Reference System. 4x4"
    " matrix stored as two dimensional array, row major "
    "order.\",\"minItems\":4,\"maxItems\":4}}}"
    ,
    /* example: */
    "{\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\""
    "WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NO"
    "RTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 Geocentric\",\"epsg\":4"
    "978},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"number\",\""
    "description\":\"Geometric scale factor applied to point "
    "coordinates\",\"minimum\":0,\"exclusiveMinimum\":true}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Georefer"
    "encing Parameters\",\"type\":\"object\",\"description\":\"Parameters used for "
    "georeferencing of the point cloud\",\"properties\":{\"trajectory_file\":{\"r"
    "equired\":[\"file_extension\"],\"type\":\"object\",\"description\":\"Trajectory "
    "data used for georeferencing of the point cloud\",\"properties\":{\"file_u"
    "uid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}}},\"body_coordinate_system_ty"
    "pe\":{\"type\":\"string\",\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: NED\",\"enum\":[\"NED\",\"ENU"
    "\"]},\"socs_to_body_matrix\":{\"items\":{\"items\":{\"type\":\"number\",\"descript"
    "ion\":\"columns\"},\"type\":\"array\",\"description\":\"rows\",\"minItems\":4,\"maxI"
    "tems\":4},\"type\":\"array\",\"description\":\"Coordinate Transformation "
    "Matrix to transform from Scanner's Own Coordinate System to Body "
    "Coordinate System. 4x4 matrix stored as two dimensional array, row "
    "major order.\",\"minItems\":4,\"maxItems\":4},\"socs_to_rocs_matrix\":{\"items"
    "\":{\"items\":{\"type\":\"number\",\"description\":\"columns\"},\"type\":\"array\",\"d"
    "escription\":\"rows\",\"minItems\":4,\"maxItems\":4},\"type\":\"array\",\"descript"
    "ion\":\"Coordinate Transformation Matrix to transform from Scanner's Own"
    " Coordinate System to Record Coordinate System. 4x4 matrix stored as "
    "two dimensional array, row major order.\",\"minItems\":4,\"maxItems\":4},\"t"
    "rajectory_offsets\":{\"type\":\"object\",\"description\":\"Correction offsets "
    "applied to the trajectory data\",\"properties\":{\"offset_yaw\":{\"type\":\"nu"
    "mber\",\"description\":\"[deg]\"},\"offset_east\":{\"type\":\"number\",\"descripti"
    "on\":\"[m]\"},\"offset_pitch\":{\"type\":\"number\",\"description\":\"[deg]\"},\"off"
    "set_roll\":{\"type\":\"number\",\"description\":\"[deg]\"},\"offset_time\":{\"type"
    "\":\"number\",\"description\":\"[s]\"},\"version\":{\"type\":\"integer\",\"descripti"
    "on\":\"Meaning of offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_north\":{\"type\":\"number\",\"description\":\"[m]"
    "\"},\"offset_height\":{\"type\":\"number\",\"description\":\"[m]\"}}}}}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\""
    ",\"file_extension\":\"pofx\"},\"socs_to_body_matrix\":[[-0.269827776749716,-"
    "0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051"
    "7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,"
    "0.0],[0.0,0.0,0.0,1.0]],\"body_coordinate_system_type\":\"NED\",\"trajector"
    "y_offsets\":{\"offset_yaw\":-0.45,\"offset_east\":0.15,\"offset_pitch\":0.01,"
    "\"offset_roll\":0.03,\"offset_time\":18.007,\"version\":0,\"offset_north\":0.0"
    "7,\"offset_height\":-0.2}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Item Nam"
    "es\",\"type\":\"object\",\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\""
    ",\"description\":\"One field per item, field name is item id, field value"
    " is item name\"}},\"additionalProperties\":false,\"description\":\"Map of "
    "item names\"}"
    ,
    /* example: */
    "{\"1\":\"Name of item with id 1\",\"2\":\"Name of item with id 2\",\"-1\":\"Name "
    "of item with id -1\",\"47\":\"Name of item with id 47\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Software"
    " License Keys\",\"type\":\"object\",\"patternProperties\":{\"^.*$\":{\"items\":{\""
    "type\":\"string\",\"description\":\"License key (example: '46AE032A - "
    "39882AC4 - 9EC0A184 - 6F163D73')\"},\"type\":\"array\",\"description\":\"Each "
    "field of the object represents a feature and holds a list of license "
    "keys, where the field name is the feature name.\",\"minItems\":1}},\"addit"
    "ionalProperties\":false,\"description\":\"License keys for software "
    "features\"}"
    ,
    /* example: */
    "{\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - 6F163D73\"],\"Full "
    "Waveform Analysis Topography with GPU support\":[\"8AB44126 - 23B92250 -"
    " 16E2689F - 34EF7E7B\"],\"MTA resolution\":[\"468E020A - 39A922E4 - "
    "B681A184 - 673E3D72\"],\"Full Waveform Analysis Topography\":[\"0FD5FF07 -"
    " 011A1255 - 9F76CACA - 8D2ED557\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"MTA "
    "Settings\",\"type\":\"object\",\"description\":\"Parameters for MTA processing"
    "\",\"properties\":{\"zone_count\":{\"maximum\":255,\"type\":\"integer\",\"descript"
    "ion\":\"Maximum number of MTA zones.\",\"minimum\":0},\"zone_width\":{\"type\":"
    "\"number\",\"description\":\"Width of a MTA zone in meter.\",\"minimum\":0},\"m"
    "odulation_depth\":{\"type\":\"number\",\"description\":\"Depth of pulse "
    "position modulation in meter.\",\"minimum\":0}}}"
    ,
    /* example: */
    "{\"zone_count\":23,\"zone_width\":149.896225,\"modulation_depth\":9.368514}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Near "
    "Range Correction Table\",\"type\":\"object\",\"properties\":{\"delta\":{\"type\":"
    "\"number\",\"description\":\"Delta between table entries [m], first entry "
    "is at range = 0 m\"},\"content\":{\"items\":{\"type\":\"number\"},\"type\":\"array"
    "\",\"description\":\"Correction value [m] to be added to the raw "
    "range\",\"minItems\":1,\"maxItems\":2000}},\"description\":\"Lookup table for "
    "range correction based on raw range\",\"required\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Noise Es"
    "timates\",\"type\":\"object\",\"properties\":{\"range_sigma\":{\"items\":{\"type\":"
    "\"number\"},\"type\":\"array\",\"description\":\"Sigma range [m]\"},\"amplitude_s"
    "igma\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Sigma "
    "amplitude [dB]\"},\"amplitude\":{\"items\":{\"type\":\"number\"},\"type\":\"array\""
    ",\"description\":\"Amplitude [dB]\"}},\"description\":\"Standard deviation "
    "for range and amplitude as a function of "
    "amplitude\",\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"]}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0."
    "54,0.482,0.432,0.39,0.354],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7."
    "0,8.0,9.0,10.0]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Notch Fi"
    "lter\",\"type\":\"object\",\"properties\":{\"amplitude_maximum\":{\"type\":\"numbe"
    "r\",\"description\":\"Maximum amplitude [dB]\",\"minimum\":0},\"range_minimum\""
    ":{\"type\":\"number\",\"description\":\"Minimum range "
    "[m]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range "
    "[m]\"}},\"description\":\"Notch filter parameters for window glass echoes\""
    ",\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"]}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_minimum\":-0.5,\"range_maximum\":0.2}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Pixel In"
    "formation\",\"type\":\"object\",\"properties\":{\"size\":{\"$ref\":\"#/definitions"
    "/pixel_size\",\"description\":\"Size of pixels in file coordinate system.\""
    "},\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size "
    "of pixels in a locally levelled cartesian coordinate system (xy). This"
    " is only used for pixels based on a map projection.\"}},\"definitions\":{"
    "\"pixel_size\":{\"items\":{\"type\":\"number\",\"description\":\"Length of pixel "
    "edge [m].\",\"minimum\":0},\"type\":\"array\",\"description\":\"Size of "
    "pixels.\",\"minItems\":2,\"maxItems\":2}},\"description\":\"Details about the "
    "pixels contained in the file\",\"required\":[\"size\"]}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Plane "
    "Patch Matching\",\"type\":\"object\",\"properties\":{\"plane_patch_file_two\":{"
    "\"$ref\":\"#/definitions/file_reference\",\"description\":\"Reference to the "
    "plane patch file two\"},\"plane_patch_file_one\":{\"$ref\":\"#/definitions/f"
    "ile_reference\",\"description\":\"Reference to the plane patch file one\"}}"
    ",\"definitions\":{\"file_reference\":{\"required\":[\"file_uuid\",\"file_path\"]"
    ",\"type\":\"object\",\"description\":\"Reference to a plane patch "
    "file\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane "
    "patch file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match file\"}}}},\"description\":\"Details "
    "about the plane patch matching "
    "process\",\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"]}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fb"
    "efa9\",\"file_path\":\"project.ptch\"},\"plane_patch_file_one\":{\"file_uuid\":"
    "\"810f5d57-eccf-49ed-b07a-0cdd109b4213\",\"file_path\":\"Record009_Line001/"
    "191025_121410_Scanner_1.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Plane "
    "Patch Statistics\",\"type\":\"object\",\"description\":\"Statistics about "
    "plane patches found by plane patch extractor\",\"properties\":{\"total_are"
    "a\":{\"type\":\"number\",\"description\":\"sum of all plane patch areas [m\\u00"
    "b2]\"},\"total_horizontal_area\":{\"type\":\"number\",\"description\":\"sum of "
    "all plane patch areas projected to horizontal plane [m\\u00b2]\"}}}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Plane "
    "Slope Class Info\",\"type\":\"object\",\"properties\":{\"settings\":{\"type\":\"ob"
    "ject\",\"description\":\"Classification settings, details see "
    "documentation of rdbplanes\",\"oneOf\":[{\"$ref\":\"#/definitions/method-1\"}"
    ",{\"$ref\":\"#/definitions/method-2\"}]},\"classes\":{\"additionalProperties\""
    ":false,\"type\":\"object\",\"description\":\"Class definition table\",\"pattern"
    "Properties\":{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"one field per "
    "class, field name is class number, field value is class name\"}}}},\"def"
    "initions\":{\"method-2\":{\"required\":[\"plane_classification_method\",\"slop"
    "ing_plane_classes_minimum_angle\",\"sloping_plane_classes_maximum_angle\""
    "],\"type\":\"object\",\"description\":\"Classification method 2\",\"properties\""
    ":{\"plane_classification_method\":{\"maximum\":2,\"type\":\"integer\",\"descrip"
    "tion\":\"method ID (=2)\",\"minimum\":2},\"sloping_plane_classes_maximum_ang"
    "le\":{\"maximum\":360.0,\"type\":\"number\",\"description\":\"maximum "
    "inclination angle of sloping plane patches [deg]\",\"minimum\":-360.0},\"s"
    "loping_plane_classes_minimum_angle\":{\"maximum\":360.0,\"type\":\"number\",\""
    "description\":\"minimum inclination angle of sloping plane patches [deg]"
    "\",\"minimum\":-360.0}}},\"method-1\":{\"required\":[\"plane_classification_me"
    "thod\",\"maximum_inclination_angle_horizontal\"],\"type\":\"object\",\"descrip"
    "tion\":\"Classification method 1\",\"properties\":{\"plane_classification_me"
    "thod\":{\"maximum\":1,\"type\":\"integer\",\"description\":\"method ID (=1)\",\"mi"
    "nimum\":1},\"maximum_inclination_angle_horizontal\":{\"maximum\":360.0,\"typ"
    "e\":\"number\",\"description\":\"maximum inclination angle of horizontal "
    "plane patches [deg]\",\"minimum\":-360.0}}}},\"description\":\"Settings and "
    "classes for plane slope "
    "classification\",\"required\":[\"settings\",\"classes\"]}"
    ,
    /* example: */
    "{\"settings\":{\"plane_classification_method\":2,\"sloping_plane_classes_ma"
    "ximum_angle\":70.0,\"sloping_plane_classes_minimum_angle\":10.0},\"classes"
    "\":{\"14\":\"horizontal, pointing down\",\"7\":\"vertical, pointing "
    "south\",\"1\":\"horizontal, pointing up\",\"2\":\"sloping, pointing up and "
    "east\",\"11\":\"sloping, pointing down and south\",\"6\":\"vertical, pointing "
    "east\",\"3\":\"sloping, pointing up and south\",\"9\":\"vertical, pointing "
    "west\",\"10\":\"sloping, pointing down and east\",\"12\":\"sloping, pointing "
    "down and north\",\"5\":\"sloping, pointing up and west\",\"4\":\"sloping, "
    "pointing up and north\",\"8\":\"vertical, pointing north\",\"13\":\"sloping, "
    "pointing down and west\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Attribute Groups\",\"type\":\"object\",\"patternProperties\":{\"^.*$\":{\"items\""
    ":{\"type\":\"string\",\"description\":\"Point attribute full name or name "
    "pattern (perl regular expression "
    "syntax)\"},\"type\":\"array\",\"description\":\"Each field of the object "
    "represents a point attribute group and holds a list of point "
    "attributes, where the field name is the group name.\",\"minItems\":1}},\"a"
    "dditionalProperties\":false,\"description\":\"Grouping and sorting of "
    "point attributes for visualization purposes\"}"
    ,
    /* example: */
    "{\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.de"
    "viation\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Other A"
    "ttributes\":[\"riegl.selected\",\"riegl.visible\"],\"Time\":[\"riegl.timestamp"
    "\"],\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"rie"
    "gl.phi\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Point "
    "Cloud Information\",\"type\":\"object\",\"description\":\"Details about point "
    "cloud files\",\"properties\":{\"comments\":{\"type\":\"string\",\"description\":\""
    "Comments\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"field_of_application\":{\"type\":\"string\",\"description\":\"Field of"
    " application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"B"
    "LS\",\"ILS\"]}}}"
    ,
    /* example: */
    "{\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\",\"field_of_application\":\"ALS\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Pose Est"
    "imation\",\"type\":\"object\",\"properties\":{\"orientation\":{\"required\":[\"rol"
    "l\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\"],\"typ"
    "e\":\"object\",\"description\":\"Orientation values and orientation "
    "accuracies, measured with IMU or inclination sensors.\",\"properties\":{\""
    "pitch\":{\"maximum\":360,\"type\":\"number\",\"description\":\"Pitch angle about"
    " scanner Y-axis [deg]\",\"minimum\":-360},\"yaw_accuracy\":{\"type\":\"number\""
    ",\"description\":\"Yaw angle accuracy [deg]\",\"minimum\":0,\"exclusiveMinimu"
    "m\":true},\"yaw\":{\"maximum\":360,\"type\":\"number\",\"description\":\"Yaw angle"
    " about scanner Z-axis [deg]\",\"minimum\":-360},\"roll\":{\"maximum\":360,\"ty"
    "pe\":\"number\",\"description\":\"Roll angle about scanner X-axis [deg]\",\"mi"
    "nimum\":-360},\"roll_accuracy\":{\"type\":\"number\",\"description\":\"Roll "
    "angle accuracy [deg]\",\"minimum\":0,\"exclusiveMinimum\":true},\"pitch_accu"
    "racy\":{\"type\":\"number\",\"description\":\"Pitch angle accuracy [deg]\",\"min"
    "imum\":0,\"exclusiveMinimum\":true}}},\"barometric_height_amsl\":{\"type\":\"n"
    "umber\",\"description\":\"Altitude determined based on the atmospheric "
    "pressure according to the standard atmosphere laws [m].\"},\"position\":{"
    "\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"horizontal_a"
    "ccuracy\",\"vertical_accuracy\",\"crs\"],\"type\":\"object\",\"description\":\"Pos"
    "ition coordinates and position accuracy values as measured by GNSS in "
    "the specified Coordinate Reference System (CRS)\",\"properties\":{\"coordi"
    "nate_2\":{\"type\":\"number\",\"description\":\"Coordinate 2 as defined by "
    "axis 2 of the specified CRS (e.g., Y, Longitude)\"},\"crs\":{\"required\":["
    "\"epsg\"],\"type\":\"object\",\"description\":\"Global Coordinate Reference Sys"
    "tem\",\"properties\":{\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known "
    "Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan"
    "dards/wkt-crs)\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG code\",\"m"
    "inimum\":0}}},\"horizontal_accuracy\":{\"type\":\"number\",\"description\":\"Hor"
    "izontal accuracy [m]\",\"minimum\":0,\"exclusiveMinimum\":true},\"vertical_a"
    "ccuracy\":{\"type\":\"number\",\"description\":\"Vertical accuracy [m]\",\"minim"
    "um\":0,\"exclusiveMinimum\":true},\"coordinate_3\":{\"type\":\"number\",\"descri"
    "ption\":\"Coordinate 3 as defined by axis 3 of the specified CRS (e.g., "
    "Z, "
    "Altitude)\"},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate "
    "1 as defined by axis 1 of the specified CRS (e.g., X, "
    "Latitude)\"}}}},\"description\":\"Estimated position and orientation "
    "information as measured by GNSS, IMU or inclination "
    "sensors\",\"required\":[\"orientation\"]}"
    ,
    /* example: */
    "{\"orientation\":{\"pitch\":1.509153024827064,\"yaw_accuracy\":1.00943378393"
    "68757,\"yaw\":101.87293630292045,\"roll\":3.14743073066123,\"roll_accuracy\""
    ":0.009433783936875745,\"pitch_accuracy\":0.009433783936875745},\"barometr"
    "ic_height_amsl\":386.7457796227932,\"position\":{\"coordinate_2\":15.645033"
    "406,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHERO"
    "ID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],A"
    "UTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,A"
    "UTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,AU"
    "THORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\"
    "\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\",\"epsg\":4979},\"horizontal_accura"
    "cy\":0.810699999332428,\"vertical_accuracy\":1.3314999341964722,\"coordina"
    "te_3\":362.7124938964844,\"coordinate_1\":48.655799473}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Pose Sen"
    "sors\",\"type\":\"object\",\"properties\":{\"accelerometer\":{\"required\":[\"unit"
    "\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\""
    "],\"type\":\"object\",\"description\":\"Accelerometer details\",\"properties\":{"
    "\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor origin "
    "in SOCS [m] at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"minimum\":0,\"exclusiveMin"
    "imum\":true},\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"de"
    "scription\":\"Relative nonlinearity, dimensionless\"},\"z_axis\":{\"$ref\":\"#"
    "/definitions/vector\",\"description\":\"Sensitive Z axis of sensor at "
    "frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"},\"y_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive Y axis of sensor at frame angle ="
    " 0\"}}},\"magnetic_field_sensor\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\""
    "z_axis\",\"offset\",\"fixed\",\"relative_nonlinearity\"],\"type\":\"object\",\"des"
    "cription\":\"Magnetic Field Sensor details\",\"properties\":{\"relative_nonl"
    "inearity\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative "
    "nonlinearity, dimensionless\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\","
    "\"description\":\"Sensitive X axis of sensor at frame angle = "
    "0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in nT\",\"minimum\":0,\"exclusiveMinimum\":true},"
    "\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z "
    "axis of sensor at frame angle = "
    "0\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Distortion "
    "of magnetic field caused by non-rotating scanner "
    "part\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to"
    " be subtracted from raw measurement values\"},\"y_axis\":{\"$ref\":\"#/defin"
    "itions/vector\",\"description\":\"Sensitive Y axis of sensor at frame "
    "angle = 0\"}}},\"gyroscope\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axi"
    "s\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"type\":\"object\",\"descrip"
    "tion\":\"Gyroscope details\",\"properties\":{\"origin\":{\"$ref\":\"#/definition"
    "s/vector\",\"description\":\"Sensor origin in SOCS [m] at frame angle = "
    "0\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = "
    "0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\",\"minimum\":0,\"exclusiveMinimum\":tru"
    "e},\"relative_nonlinearity\":{\"$ref\":\"#/definitions/vector\",\"description"
    "\":\"Relative nonlinearity, dimensionless\"},\"z_axis\":{\"$ref\":\"#/definiti"
    "ons/vector\",\"description\":\"Sensitive Z axis of sensor at frame angle ="
    " 0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to "
    "be subtracted from raw measurement values\"},\"y_axis\":{\"$ref\":\"#/defini"
    "tions/vector\",\"description\":\"Sensitive Y axis of sensor at frame angle"
    " = 0\"}}}},\"definitions\":{\"vector\":{\"items\":{\"type\":\"number\",\"descripti"
    "on\":\"Index 0=X, 1=Y, 2=Z component\"},\"type\":\"array\",\"minItems\":3,\"maxI"
    "tems\":3}},\"description\":\"Details on position and orientation sensors\","
    "\"required\":[\"gyroscope\",\"accelerometer\",\"magnetic_field_sensor\"]}"
    ,
    /* example: */
    "{\"accelerometer\":{\"origin\":[0.026900000870227814,-0.03999999910593033,"
    "-0.08950000256299973],\"x_axis\":[-15008.123046875,56.956390380859375,-6"
    "0.5175666809082],\"unit\":6.666666740784422e-05,\"relative_nonlinearity\":"
    "[0.0,0.0,0.0],\"z_axis\":[1.639882206916809,15166.744140625,-116.9974288"
    "9404297],\"offset\":[-733.3636474609375,58.969032287597656,1060.25500488"
    "28125],\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.370117187"
    "5]},\"magnetic_field_sensor\":{\"relative_nonlinearity\":[0.0,0.0,0.0],\"x_"
    "axis\":[-0.011162743903696537,-2.315962774446234e-05,0.0001681884459685"
    "5342],\"unit\":91.74311828613281,\"z_axis\":[0.00041987866279669106,7.8769"
    "77906562388e-05,0.011407104320824146],\"fixed\":[-1576.010498046875,1596"
    ".081787109375,0.0],\"offset\":[-23812.052734375,5606.57666015625,2493.28"
    "125],\"y_axis\":[0.00027888521435670555,-0.011427424848079681,-5.2048297"
    "22060822e-05]},\"gyroscope\":{\"origin\":[0.026900000870227814,-0.03999999"
    "910593033,-0.08950000256299973],\"x_axis\":[-121.195556640625,0.82197141"
    "64733887,0.2313031703233719],\"unit\":0.00014544410805683583,\"relative_n"
    "onlinearity\":[2.888176311444113e-07,1.06274164579645e-07,-1.7186295080"
    "634935e-39],\"z_axis\":[0.555869996547699,119.22135162353516,0.467585027"
    "217865],\"offset\":[-50.92609786987305,146.15643310546875,62.43272781372"
    "07],\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.5894775390625"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Pulse "
    "Position Modulation\",\"type\":\"object\",\"properties\":{\"length\":{\"maximum\""
    ":255,\"type\":\"integer\",\"description\":\"Length of code\",\"minimum\":0},\"num"
    "_mod_ampl\":{\"maximum\":255,\"type\":\"integer\",\"description\":\"Number of "
    "different modulation amplitudes (2: binary modulation)\",\"minimum\":0},\""
    "code_phase_mode\":{\"maximum\":255,\"type\":\"integer\",\"description\":\"0: no "
    "synchronization, 1: toggle between 2 phases, 2: increment with phase_i"
    "ncrement\",\"minimum\":0},\"phase_step\":{\"maximum\":255,\"type\":\"integer\",\"d"
    "escription\":\"Step width in phase of modulation code from line to line\""
    ",\"minimum\":0},\"pulse_interval\":{\"items\":{\"type\":\"number\",\"minimum\":0},"
    "\"type\":\"array\",\"description\":\"Explicit table of the pulse position "
    "modulation used for MTA resolution. Table gives times between "
    "successive laser pulses in seconds.\"}},\"description\":\"Laser pulse "
    "position modulation used for MTA "
    "resolution\",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"]}"
    ,
    /* example: */
    "{\"length\":31,\"num_mod_ampl\":2,\"code_phase_mode\":2,\"phase_step\":5,\"puls"
    "e_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821"
    "875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-"
    "06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2."
    "821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.75937"
    "5e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06"
    ",2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06]}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Range St"
    "atistics\",\"type\":\"object\",\"properties\":{\"average\":{\"type\":\"number\",\"de"
    "scription\":\"Average "
    "value\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"}},\"description\":\"Statistics about target distance wrt. SOCS"
    " origin\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"]}"
    ,
    /* example: */
    "{\"average\":15.49738,\"maximum\":574.35,\"minimum\":0.919,\"std_dev\":24.349}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Receiver"
    " Internals\",\"type\":\"object\",\"properties\":{\"t\":{\"additionalProperties\":"
    "false,\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/defin"
    "itions/fp\",\"description\":\"one field per channel, field name is channel"
    " index\"}}},\"tbl\":{\"items\":{\"$ref\":\"#/definitions/fp_table\"},\"type\":\"ar"
    "ray\",\"description\":\"various internal data\",\"minItems\":1},\"a\":{\"items\":"
    "{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Amplitude [dB]\",\"minIt"
    "ems\":1,\"maxItems\":256},\"nt\":{\"maximum\":255,\"type\":\"integer\",\"descripti"
    "on\":\"Number of traces\",\"minimum\":0},\"ns\":{\"maximum\":4095,\"type\":\"integ"
    "er\",\"description\":\"Number of "
    "samples\",\"minimum\":0},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED,"
    " use 'riegl.exponential_decomposition' "
    "instead\"},\"sr\":{\"type\":\"number\",\"description\":\"Sample rate [Hz]\",\"mini"
    "mum\":0,\"exclusiveMinimum\":true},\"si\":{\"maximum\":255,\"type\":\"number\",\"d"
    "escription\":\"Start index (hw_start)\",\"minimum\":0},\"mw\":{\"maximum\":4095"
    ",\"type\":\"number\",\"description\":\"Maximum weight\",\"minimum\":0,\"exclusive"
    "Minimum\":true}},\"definitions\":{\"fp\":{\"required\":[\"s\",\"w\"],\"type\":\"obje"
    "ct\",\"description\":\"Fingerprint values\",\"properties\":{\"s\":{\"items\":{\"it"
    "ems\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":1,\"maxItems\":4096},\"t"
    "ype\":\"array\",\"minItems\":1,\"maxItems\":256},\"w\":{\"items\":{\"items\":{\"type"
    "\":\"number\"},\"type\":\"array\",\"minItems\":5,\"maxItems\":5},\"type\":\"array\",\""
    "minItems\":1,\"maxItems\":256}}},\"fp_table_row\":{\"maxItems\":2048,\"type\":\""
    "array\",\"minItems\":1,\"items\":{\"type\":\"number\"}},\"fp_table\":{\"required\":"
    "[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"type\":\"object\",\"desription\":\"scanner "
    "internal data\",\"properties\":{\"ny\":{\"max\":2048,\"type\":\"integer\",\"descri"
    "ption\":\"number of y entries\",\"min\":1},\"tc\":{\"max\":255,\"type\":\"integer\""
    ",\"description\":\"table data type "
    "code\",\"min\":0},\"ch\":{\"max\":255,\"type\":\"integer\",\"description\":\"channel"
    " number\",\"min\":0},\"tv\":{\"maxItems\":2048,\"type\":\"array\",\"minItems\":1,\"i"
    "tems\":{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\""
    "}]}},\"nx\":{\"max\":2048,\"type\":\"integer\",\"description\":\"number of x "
    "entries\",\"min\":1}}}},\"description\":\"Receiver Internals\"}"
    ,
    /* example: */
    "{\"t\":{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,8"
    "6,126,134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134"
    ",31],[78,86,126,134,31]]}},\"tbl\":[{\"ny\":2,\"tc\":1,\"ch\":0,\"tv\":[[1,2,3,4"
    ",5],[1.1,2.2,3.3,4.4,5.5]],\"nx\":5}],\"a\":[-1.55],\"nt\":128,\"ns\":400,\"sr\""
    ":7959997000.0,\"si\":48,\"mw\":31}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Reflecta"
    "nce Calculation Table\",\"type\":\"object\",\"properties\":{\"delta\":{\"type\":\""
    "number\",\"description\":\"Delta between table entries [m], first entry is"
    " at range = 0 m\"},\"content\":{\"items\":{\"type\":\"number\"},\"type\":\"array\","
    "\"description\":\"Correction value [dB] to be added to the "
    "amplitude\",\"minItems\":1,\"maxItems\":2000}},\"description\":\"Lookup table "
    "for reflectance calculation based on amplitude and "
    "range\",\"required\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Near-ran"
    "ge reflectance correction\",\"type\":\"object\",\"properties\":{\"reflectance_"
    "correction_db\":{\"items\":{\"items\":{\"type\":\"number\",\"description\":\"colum"
    "ns (each value corresponds to an "
    "angle)\"},\"type\":\"array\",\"description\":\"rows (each array corresponds to"
    " a range)\"},\"type\":\"array\",\"description\":\"Near range reflectance "
    "correction in dB as a function of range over angle\"},\"ranges_m\":{\"item"
    "s\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"Range [m]\"},\"line_a"
    "ngles_deg\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"An"
    "gle [deg]\"}},\"description\":\"Range-dependent and scan-angle-dependent "
    "correction of reflectance reading\",\"required\":[\"ranges_m\",\"line_angles"
    "_deg\",\"reflectance_correction_db\"]}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"ra"
    "nges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2"
    ".5,3.0,3.5,4.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Scan Pat"
    "tern\",\"properties\":{\"rectangular\":{\"required\":[\"phi_start\",\"phi_stop\","
    "\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta_increment\"],\"type\":\""
    "object\",\"description\":\"Rectangular Field Of View Scan Pattern\",\"proper"
    "ties\":{\"phi_stop\":{\"maximum\":720.0,\"type\":\"number\",\"description\":\"Stop"
    " phi angle in SOCS [deg]\",\"minimum\":0.0},\"theta_start\":{\"maximum\":180."
    "0,\"type\":\"number\",\"description\":\"Start theta angle in SOCS [deg]\",\"min"
    "imum\":0.0},\"program\":{\"$ref\":\"#/definitions/program\"},\"theta_stop\":{\"m"
    "aximum\":180.0,\"type\":\"number\",\"description\":\"Stop theta angle in SOCS "
    "[deg]\",\"minimum\":0.0},\"phi_increment\":{\"maximum\":90.0,\"type\":\"number\","
    "\"description\":\"Increment of phi angle in SOCS [deg]\",\"minimum\":0.0},\"t"
    "heta_increment\":{\"maximum\":90.0,\"type\":\"number\",\"description\":\"Increme"
    "nt of theta angle in SOCS [deg]\",\"minimum\":0.0},\"phi_start\":{\"maximum\""
    ":360.0,\"type\":\"number\",\"description\":\"Start phi angle in SOCS [deg]\",\""
    "minimum\":0.0}}},\"segments\":{\"required\":[\"list\"],\"type\":\"object\",\"descr"
    "iption\":\"Segmented Line Scan Pattern\",\"properties\":{\"program\":{\"$ref\":"
    "\"#/definitions/program\"},\"list\":{\"items\":{\"required\":[\"start\",\"stop\",\""
    "increment\"],\"type\":\"object\",\"description\":\"Line Scan Segment\",\"propert"
    "ies\":{\"increment\":{\"maximum\":90.0,\"type\":\"number\",\"description\":\"Incre"
    "ment of angle in SOCS [deg]\",\"minimum\":0.0},\"start\":{\"maximum\":360.0,\""
    "type\":\"number\",\"description\":\"Start angle in SOCS [deg]\",\"minimum\":0.0"
    "},\"stop\":{\"maximum\":720.0,\"type\":\"number\",\"description\":\"Stop angle in"
    " SOCS [deg]\",\"minimum\":0.0}}},\"type\":\"array\"}}},\"line\":{\"required\":[\"s"
    "tart\",\"stop\",\"increment\"],\"type\":\"object\",\"description\":\"Line Scan Pat"
    "tern\",\"properties\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"increm"
    "ent\":{\"maximum\":90.0,\"type\":\"number\",\"description\":\"Increment of angle"
    " in SOCS [deg]\",\"minimum\":0.0},\"start\":{\"maximum\":360.0,\"type\":\"number"
    "\",\"description\":\"Start angle in SOCS [deg]\",\"minimum\":0.0},\"stop\":{\"ma"
    "ximum\":720.0,\"type\":\"number\",\"description\":\"Stop angle in SOCS "
    "[deg]\",\"minimum\":0.0}}}},\"description\":\"Scan pattern description\",\"def"
    "initions\":{\"program\":{\"required\":[\"name\"],\"type\":\"object\",\"description"
    "\":\"Measurement "
    "program\",\"properties\":{\"name\":{\"type\":\"string\",\"description\":\"Name of "
    "measurement "
    "program\"},\"laser_prr\":{\"type\":\"number\",\"description\":\"Laser Pulse "
    "Repetition Rate [Hz]\",\"minimum\":0,\"exclusiveMinimum\":false}}}}}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_stop\":270.0,\"theta_start\":30.0,\"program\":{\"name\":"
    "\"High Speed\",\"laser_prr\":100000.0},\"theta_stop\":130.0,\"phi_increment\":"
    "0.04,\"theta_increment\":0.04,\"phi_start\":45.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Shot "
    "Information\",\"type\":\"object\",\"description\":\"Details about laser shot f"
    "iles\",\"properties\":{\"shot_file\":{\"type\":\"object\",\"properties\":{\"file_u"
    "uid\":{\"type\":\"string\",\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading dot\"}},\"required\":[\"file_extension\"]}}}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Stored f"
    "ilters\",\"type\":\"object\",\"properties\":{\"activated\":{\"type\":\"boolean\",\"d"
    "escription\":\"Apply ('true') or ignore ('false') all filters\"},\"filters"
    "\":{\"items\":{\"required\":[\"activated\",\"title\",\"description\",\"filter\"],\"t"
    "ype\":\"object\",\"description\":\"Point filter "
    "definition\",\"properties\":{\"title\":{\"type\":\"string\",\"description\":\"A "
    "short filter title (e.g. for display in a selection "
    "list)\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or"
    " ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter "
    "string to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"}}},\"type\":\"array\",\"description\":\"List of point "
    "filters\"}},\"description\":\"Point filters applied in addition to the "
    "application-defined filters\",\"required\":[\"activated\",\"filters\"]}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"title\":\"Ignore uncertain points from "
    "MTA resolution\",\"activated\":false,\"description\":\"Ignore points with "
    "uncertain MTA zone assignment\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\"},{\"title\":\"Ignore points below dynamic trigger "
    "level\",\"activated\":false,\"description\":\"Ignore points with an echo "
    "signal amplitude below the dynamic "
    "trigger\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\"},{\"title\":\"Ignore points outside outer "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are outside "
    "the outer AABB in BOCS\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\"},{\"title\":\"Ignore points inside inner "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are inside "
    "the inner AABB in BOCS\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"System D"
    "escription\",\"type\":\"object\",\"properties\":{\"$class\":{\"type\":\"string\",\"d"
    "escription\":\"Object class name\",\"enum\":[\"Document\"]},\"timestamp\":{\"typ"
    "e\":\"string\",\"description\":\"Date and time of creation (e.g. 2019-06-19T"
    "13:32:10+02:00)\"},\"version\":{\"type\":\"string\",\"description\":\"Document "
    "format version\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the "
    "author that created the "
    "document\"},\"system\":{\"type\":\"object\",\"description\":\"The actual system "
    "description, details see documentation of RIEGL System "
    "Description\"}},\"description\":\"Details of major system components like "
    "lidar sensors, cameras and navigation devices\",\"required\":[\"$class\",\"v"
    "ersion\",\"author\",\"timestamp\",\"system\"]}"
    ,
    /* example: */
    "{\"$class\":\"Document\",\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"version\""
    ":\"1.2.1\",\"author\":\"RIEGL LMS GmbH, Austria\",\"system\":{\"details\":\"see "
    "documentation of RIEGL System Description\"}}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Temperat"
    "ure Calculation Table\",\"type\":\"object\",\"properties\":{\"Si\":{\"$ref\":\"#/d"
    "efinitions/conversion_table\",\"description\":\"Conversion table for Si ch"
    "annel\"},\"InGaAs_Si_Difference\":{\"$ref\":\"#/definitions/conversion_table"
    "\",\"description\":\"Conversion table for InGaAs - Si difference\"},\"InGaAs"
    "\":{\"$ref\":\"#/definitions/conversion_table\",\"description\":\"Conversion "
    "table for InGaAs channel\"}},\"definitions\":{\"conversion_table\":{\"type\":"
    "\"object\",\"properties\":{\"temperature\":{\"items\":{\"type\":\"number\"},\"type\""
    ":\"array\",\"description\":\"Temperature [\\u00b0C]\"},\"value\":{\"items\":{\"typ"
    "e\":\"number\"},\"type\":\"array\",\"description\":\"LSB "
    "[1]\"}},\"required\":[\"value\",\"temperature\"]}},\"description\":\"Conversion "
    "of background radiation raw values to temperatures in \\u00b0C\"}"
    ,
    /* example: */
    "{\"Si\":{\"temperature\":[546.300048828125,548.8164051212026,551.314393850"
    "0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299"
    "86177,564.4104671126105,567.0002936624203],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "_Si_Difference\":{\"temperature\":[1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,"
    "1744.7813348796044,1681.9971312601092,1622.3944822534868],\"value\":[100"
    "0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036"
    "774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0"
    "411999877924]},\"InGaAs\":{\"temperature\":[307.22196722535614,309.1153478"
    "247277,311.1188086915047,313.10025350480055,315.2137946389828,317.2172"
    "555057597,319.2207163725366,321.2021611858325,323.3157023200148],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Time Bas"
    "e\",\"type\":\"object\",\"properties\":{\"source\":{\"type\":\"string\",\"descriptio"
    "n\":\"Timestamp source\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"]},\"epoch\":{\"type\""
    ":\"string\",\"description\":\"Date and time of timestamp '0' as proposed by"
    " RFC 3339 (e.g. 2015-10-27T00:00:00+01:00).\"},\"system\":{\"type\":\"string"
    "\",\"description\":\"Time system (time "
    "standard)\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"]}},\"description\":\"Base of "
    "timestamps (epoch)\",\"required\":[\"epoch\",\"source\"]}"
    ,
    /* example: */
    "{\"source\":\"GNSS\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Trajecto"
    "ry Information\",\"type\":\"object\",\"properties\":{\"location\":{\"type\":\"stri"
    "ng\",\"description\":\"Project location, e.g. city/state/country\"},\"time_i"
    "nterval\":{\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"type\":"
    "\"object\",\"description\":\"Time interval statistics\",\"properties\":{\"avera"
    "ge\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time interval "
    "[s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals "
    "[s]\"}}},\"navigation_frame\":{\"type\":\"string\",\"description\":\"Navigation "
    "frame (NED: North-East-Down, ENU: East-North-Up)\",\"enum\":[\"unknown\",\"N"
    "ED\",\"ENU\"]},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"field_of_application\":{\"type\":\"string\",\"description\":\"Field of"
    " application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"B"
    "LS\",\"ILS\"]},\"settings\":{\"type\":\"string\",\"description\":\"Settings used "
    "to calculate the trajectory (descriptive "
    "text)\"},\"software\":{\"type\":\"string\",\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the "
    "file)\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation device, "
    "e.g. "
    "name/type/serial\"},\"company\":{\"type\":\"string\",\"description\":\"Company "
    "name\"}},\"description\":\"Details about position+orientation "
    "files\",\"required\":[\"time_interval\",\"navigation_frame\"]}"
    ,
    /* example: */
    "{\"location\":\"Horn\",\"time_interval\":{\"average\":0.00500053,\"maximum\":0.0"
    "05004883,\"minimum\":0.00500032,\"std_dev\":5.51e-07},\"navigation_frame\":\""
    "NED\",\"project\":\"Campaign 3\",\"field_of_application\":\"MLS\",\"settings\":\"d"
    "efault\",\"software\":\"Navigation Software XYZ\",\"device\":\"IMU Model 12/1,"
    " Serial# 12345\",\"company\":\"RIEGL LMS\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"TTIP Con"
    "figuration\",\"type\":\"object\",\"properties\":{\"in_polarity\":{\"type\":\"integ"
    "er\",\"description\":\"0 .. positive edge, 1 .. negative edge\",\"minimum\":0"
    "},\"out_duration\":{\"type\":\"integer\",\"description\":\"output pulse "
    "duration [0.1 msec]\",\"minimum\":0},\"in_min_duration\":{\"type\":\"integer\","
    "\"description\":\"input signals with smaller pulse durations are ignored "
    "[0.1 msec]\",\"minimum\":0},\"channel\":{\"type\":\"integer\",\"description\":\"ID"
    " of input/output channel\",\"minimum\":0},\"dmi_dist_per_tick\":{\"type\":\"nu"
    "mber\",\"description\":\"dmi, distance per tick, just informative "
    "[m]\"},\"ttip_version\":{\"type\":\"integer\",\"description\":\"following main.s"
    "ub.ss.sss\",\"minimum\":0},\"num_channel\":{\"type\":\"integer\",\"description\":"
    "\"number of input/output channels\",\"minimum\":0},\"ext_delay\":{\"type\":\"in"
    "teger\",\"description\":\"external trigger, time delay [0.1 msec]\",\"minimu"
    "m\":0},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"out_delay\":{\"type\":\"integer\",\"description\":\"output pulse "
    "initial delay after start [0.1 "
    "msec]\",\"minimum\":0},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, "
    "increment in ticks\"},\"out_polarity\":{\"type\":\"integer\",\"description\":\"0"
    " .. positive edge, 1 .. negative edge\",\"minimum\":0},\"dmi_min_time\":{\"t"
    "ype\":\"integer\",\"description\":\"dmi, minimum time interval between "
    "trigger events [0.1 "
    "msec]\",\"minimum\":0},\"ext_channel\":{\"type\":\"integer\",\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates none\",\"minimum"
    "\":0},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"dmi_max_time\":{\"type\":\"integer\",\"description\":\"dmi, maximum "
    "time interval between trigger events [0.1 msec]\",\"minimum\":0},\"in_max_"
    "duration\":{\"type\":\"integer\",\"description\":\"stops measurement of pulse "
    "duration of input signal [0.1 msec]\",\"minimum\":0},\"in_max_delay\":{\"typ"
    "e\":\"integer\",\"description\":\"maximum delay to output pulse before fake "
    "event is generated [0.1 msec], zero indicates that no fake events are "
    "generated\",\"minimum\":0},\"out_interval\":{\"type\":\"integer\",\"description\""
    ":\"output pulse interval [0.1 msec]\",\"minimum\":0},\"out_num_pulses\":{\"ty"
    "pe\":\"integer\",\"description\":\"number of output pulses to be generated, "
    "0 .. infinite\",\"minimum\":0},\"ext_subdivider\":{\"type\":\"integer\",\"descri"
    "ption\":\"reduces the frequency, default "
    "1\",\"minimum\":0},\"output_usage\":{\"type\":\"integer\",\"description\":\"0 .. "
    "no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static "
    "high\",\"minimum\":0},\"ext_signal\":{\"type\":\"integer\",\"description\":\"0 .. "
    "use input signal, 1 .. use output signal of "
    "channel\",\"minimum\":0},\"input_usage\":{\"type\":\"integer\",\"description\":\"0"
    " .. deactivated, 1 .. just detecting and timestamping\",\"minimum\":0},\"e"
    "xt_bitmask\":{\"type\":\"integer\",\"description\":\"defines which of the "
    "internal pulse generators are to be "
    "started\",\"minimum\":0}},\"description\":\"Trigger-Timestamping-Unit/IP con"
    "figuration\",\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ex"
    "t_signal\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_m"
    "in_time\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\""
    "input_descr\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration"
    "\",\"out_interval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_du"
    "ration\",\"in_max_duration\",\"in_max_delay\"]}"
    ,
    /* example: */
    "{\"in_polarity\":0,\"out_duration\":300,\"in_min_duration\":0,\"channel\":0,\"d"
    "mi_dist_per_tick\":0.0,\"ttip_version\":1,\"num_channel\":9,\"ext_delay\":0,\""
    "output_descr\":\"Port 1 - Trigger\",\"out_delay\":0,\"dmi_incr\":0,\"out_polar"
    "ity\":0,\"dmi_min_time\":0,\"ext_channel\":32,\"input_descr\":\"Port 1 - Expos"
    "ure\",\"dmi_max_time\":0,\"in_max_duration\":10000,\"in_max_delay\":9990,\"out"
    "_interval\":10000,\"out_num_pulses\":1,\"ext_subdivider\":1,\"output_usage\":"
    "1,\"ext_signal\":0,\"input_usage\":1,\"ext_bitmask\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Vertex "
    "Information\",\"type\":\"object\",\"description\":\"Details about vertex file\""
    ",\"properties\":{\"vertex_file\":{\"type\":\"object\",\"properties\":{\"file_uuid"
    "\":{\"type\":\"string\",\"description\":\"File's Universally Unique Identifier"
    " (RFC 4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex "
    "file extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}}}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Voxel In"
    "formation\",\"type\":\"object\",\"definitions\":{\"voxel_type\":{\"default\":\"cen"
    "troid\",\"description\":\"Whether a point in a voxel represents its center"
    " or its centroid. If type is <tt>index</tt> there is no point but only"
    " an integer voxel index.\",\"enum\":[\"center\",\"centroid\",\"index\"]},\"voxel"
    "_size_cubic\":{\"$ref\":\"#/definitions/edge_length\",\"type\":\"number\"},\"edg"
    "e_length\":{\"type\":\"number\",\"description\":\"Length of voxel edge [m].\",\""
    "minimum\":0,\"exclusiveMinimum\":true},\"voxel_size\":{\"items\":{\"$ref\":\"#/d"
    "efinitions/edge_length\"},\"type\":\"array\",\"description\":\"Size of voxels."
    "\",\"minItems\":3,\"maxItems\":3},\"voxel_origin_point\":{\"items\":{\"type\":\"nu"
    "mber\"},\"type\":\"array\",\"description\":\"Origin point for all voxel "
    "indices in voxel CRS.\",\"minItems\":3,\"maxItems\":3},\"voxel_origin_enum\":"
    "{\"default\":\"corner\",\"description\":\"Defines whether the voxel's center "
    "or a corner is placed on CRS origin <tt>(0/0/0)</tt>.\",\"enum\":[\"center"
    "\",\"corner\"]},\"shape_thresholds\":{\"properties\":{\"line\":{\"type\":\"number\""
    ",\"description\":\"If the biggest eigenvalue is bigger than the median "
    "eigenvalue * line_threshold, the voxel is considered a line.\",\"minimum"
    "\":1,\"exclusiveMinimum\":true},\"plane\":{\"maximum\":1,\"type\":\"number\",\"exc"
    "lusiveMaximum\":true,\"description\":\"If the smallest eigenvalue is "
    "smaller than the median eigenvalue * plane_threshold, the voxel is "
    "considered a plane.\",\"minimum\":0,\"exclusiveMinimum\":true}},\"type\":\"obj"
    "ect\",\"description\":\"Thresholds used to compute the voxel's shape_id "
    "value.\",\"required\":[\"plane\",\"line\"]}},\"description\":\"Details about the"
    " voxels contained in the file\",\"oneOf\":[{\"additionalProperties\":false,"
    "\"properties\":{\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size\":"
    "{\"description\":\"Size of voxels in file coordinate system.\",\"oneOf\":[{\""
    "$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size_cu"
    "bic\"}]},\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\"},\"sha"
    "pe_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"}},\"required\":["
    "\"size\",\"voxel_origin\",\"voxel_type\"]},{\"additionalProperties\":false,\"pr"
    "operties\":{\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"size\":{\"$"
    "ref\":\"#/definitions/voxel_size\",\"description\":\"Size of voxels in file "
    "coordinate system.\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\"#/definitions/v"
    "oxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel_origin_point\",\"descrip"
    "tion\":\"The base point of the voxel grid. Used together with "
    "<tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual point c"
    "oordinates.\"}]},\"size_llcs\":{\"$ref\":\"#/definitions/voxel_size\",\"descri"
    "ption\":\"Size of voxels in a locally levelled cartesian coordinate "
    "system (xyz). This is only used for voxels based on a map projection.\""
    "},\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"refere"
    "nce_point\":{\"items\":{\"maximum\":180,\"type\":\"number\",\"minimum\":-180},\"ty"
    "pe\":\"array\",\"description\":\"Point in WGS84 geodetic decimal degree "
    "(EPSG:4326) that was used to compute the projection distortion "
    "parameters. The coefficient order is latitude, longitude. Only voxels "
    "with corresponding geo_tag, voxel_size and reference_point can be "
    "reliably processed together. This entry is available for voxel files "
    "in projected CRS only.\",\"minItems\":2,\"maxItems\":2}},\"required\":[\"refer"
    "ence_point\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_type\"]}]}"
    ,
    /* example: */
    "{\"voxel_type\":\"centroid\",\"size\":[0.5971642834779395,0.5971642834779395"
    ",0.5143705304787237],\"voxel_origin\":\"corner\",\"size_llcs\":[0.5156575252"
    "891171,0.5130835356683303,0.5143705304787237],\"shape_thresholds\":{\"lin"
    "e\":6,\"plane\":0.16},\"reference_point\":[48,16]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Waveform"
    " Averaging Settings\",\"type\":\"object\",\"properties\":{\"trim\":{\"maximum\":0"
    ".5,\"default\":0,\"type\":\"number\",\"description\":\"Percentage for robust av"
    "eraging.\",\"minimum\":0},\"mta_zone\":{\"type\":\"integer\",\"description\":\"Fix"
    "ed MTA zone for averaging.\",\"minimum\":1},\"num_shots\":{\"type\":\"integer\""
    ",\"description\":\"Number of consecutive shots to be used for "
    "averaging.\",\"minimum\":1}},\"description\":\"Settings for waveform "
    "averaging\",\"required\":[\"num_shots\",\"mta_zone\"]}"
    ,
    /* example: */
    "{\"trim\":0.05,\"mta_zone\":1,\"num_shots\":7}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Waveform"
    " Information\",\"type\":\"object\",\"properties\":{\"range_offset_m\":{\"type\":\""
    "number\",\"description\":\"Calibrated device specific range offset for "
    "waveform analysis by system response fitting in meters.\"},\"range_offse"
    "t_waveform_samples_m\":{\"type\":\"number\",\"description\":\"Calibrated "
    "device specific range offset for waveform samples in meters.\"},\"sample"
    "_data_files\":{\"items\":{\"type\":\"object\",\"required\":[\"channel\",\"channel_"
    "name\",\"sample_interval\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"f"
    "ile_extension\"],\"properties\":{\"delta_st\":{\"type\":\"number\",\"description"
    "\":\"reserved\"},\"channel\":{\"maximum\":255,\"type\":\"integer\",\"exclusiveMaxi"
    "mum\":false,\"description\":\"Sample block channel number (255 = invalid)\""
    ",\"minimum\":0,\"exclusiveMinimum\":false},\"laser_wavelength\":{\"type\":\"num"
    "ber\",\"description\":\"Laser wavelength in meters (0 = unknown)\",\"minimum"
    "\":0,\"exclusiveMinimum\":false},\"file_uuid\":{\"type\":\"string\",\"descriptio"
    "n\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample data "
    "file extension, without the leading dot\"},\"sample_bits\":{\"maximum\":32,"
    "\"type\":\"integer\",\"exclusiveMaximum\":false,\"description\":\"Bitwidth of "
    "samples (e.g. 10 bit, 12 bit)\",\"minimum\":0,\"exclusiveMinimum\":false},\""
    "sample_interval\":{\"type\":\"number\",\"description\":\"Sampling interval in "
    "seconds\",\"minimum\":0,\"exclusiveMinimum\":false},\"channel_name\":{\"type\":"
    "\"string\",\"description\":\"Sample block channel name\"}}},\"type\":\"array\"},"
    "\"sample_block_file\":{\"type\":\"object\",\"required\":[\"file_extension\"],\"pr"
    "operties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}}}},\"description\":\"Details "
    "about waveform "
    "files\",\"required\":[\"sample_block_file\",\"sample_data_files\"]}"
    ,
    /* example: */
    "{\"range_offset_waveform_samples_m \":7.283,\"range_offset_m\":3.1415,\"sam"
    "ple_data_files\":[{\"delta_st\":0,\"file_uuid\":\"da084413-e3e8-4655-a122-07"
    "1de8490d8e\",\"channel\":0,\"channel_name\":\"high_power\",\"file_extension\":\""
    "sp0\",\"sample_interval\":1.00503e-09,\"laser_wavelength\":0,\"sample_bits\":"
    "12},{\"delta_st\":0,\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\""
    "channel\":1,\"channel_name\":\"low_power\",\"file_extension\":\"sp1\",\"sample_i"
    "nterval\":1.00503e-09,\"laser_wavelength\":0,\"sample_bits\":12},{\"delta_st"
    "\":0,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"channel\":5,\"ch"
    "annel_name\":\"wwf\",\"file_extension\":\"sp5\",\"sample_interval\":1.00503e-09"
    ",\"laser_wavelength\":0,\"sample_bits\":12}],\"sample_block_file\":{\"file_uu"
    "id\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\"}}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Waveform"
    " Settings\",\"type\":\"array\",\"description\":\"Scanner settings for waveform"
    " output\",\"items\":{\"type\":\"object\",\"properties\":{\"smart_enabled\":{\"type"
    "\":\"boolean\",\"description\":\"Smart waveform output "
    "enabled\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold "
    "for range less than "
    "[m]\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude less than "
    "[dB]\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask "
    "for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, "
    "...\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample "
    "block, e.g.: wfm, "
    "wwf\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range greater than "
    "[m]\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"}},\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mask\"]}}"
    ,
    /* example: */
    "[{\"smart_enabled\":true,\"enabled\":true,\"pass_rng_less\":13.11,\"pass_ampl"
    "_less\":5.0,\"channel_idx_mask\":11,\"pass_ampl_greater\":1.0,\"sbl_name\":\"w"
    "fm\",\"pass_rng_greater\":9.27},{\"channel_idx_mask\":32,\"enabled\":false,\"s"
    "bl_name\":\"wwf\"}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Window A"
    "nalysis\",\"type\":\"object\",\"properties\":{\"settings\":{\"type\":\"object\",\"pr"
    "operties\":{\"range\":{\"type\":\"object\",\"properties\":{\"additive_value\":{\"t"
    "ype\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}},\"required\":[\"sigma_fa"
    "ctor\",\"additive_value\"]},\"amplitude\":{\"type\":\"object\",\"properties\":{\"a"
    "dditive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}},\"re"
    "quired\":[\"sigma_factor\",\"additive_value\"]}},\"required\":[\"range\",\"ampli"
    "tude\"]},\"result\":{\"type\":\"object\",\"properties\":{\"amplitude_mean\":{\"ite"
    "ms\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"[dB]\"},\"amplitude_"
    "sigma\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"[dB]\"}"
    ",\"angle\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"[deg"
    "]\"},\"timestamp\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description"
    "\":\"[s]\"},\"range_mean\":{\"items\":{\"type\":\"number\"},\"type\":\"array\",\"descr"
    "iption\":\"[m]\"},\"range_sigma\":{\"items\":{\"type\":\"number\"},\"type\":\"array\""
    ",\"description\":\"[m]\"},\"amplitude_offset\":{\"items\":{\"type\":\"number\"},\"t"
    "ype\":\"array\",\"description\":\"[dB]\"}},\"required\":[\"angle\",\"range_mean\",\""
    "range_sigma\",\"amplitude_mean\",\"amplitude_sigma\",\"amplitude_offset\"]},\""
    "filter\":{\"type\":\"object\",\"properties\":{\"range_min\":{\"items\":{\"type\":\"n"
    "umber\"},\"type\":\"array\",\"description\":\"[m]\"},\"amplitude_max\":{\"items\":{"
    "\"type\":\"number\"},\"type\":\"array\",\"description\":\"[dB]\"},\"angle\":{\"items\""
    ":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"[deg]\"},\"range_max\":{"
    "\"items\":{\"type\":\"number\"},\"type\":\"array\",\"description\":\"[m]\"}},\"requir"
    "ed\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"]}},\"description\":"
    "\"Window analysis data estimated from scandata and resulting filter "
    "parameters\",\"required\":[\"result\",\"filter\",\"settings\"]}"
    ,
    /* example: */
    "{\"settings\":{\"range\":{\"additive_value\":0.1,\"sigma_factor\":8},\"amplitud"
    "e\":{\"additive_value\":1.0,\"sigma_factor\":4}},\"result\":{\"amplitude_mean\""
    ":[5.347396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983"
    "473,5.007885,5.002441,4.982],\"amplitude_sigma\":[0.4272844,0.4298479,0."
    "4236816,0.4283583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001,0."
    "4345487,0.4540681],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15"
    ".7,15.8,15.9],\"timestamp\":[408.4441,411.4443],\"range_mean\":[0.1105621,"
    "0.1079564,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0"
    ".1051523,0.1058445,0.1031261],\"range_sigma\":[0.01869652,0.02151435,0.0"
    "1747969,0.01918765,0.01945776,0.01934862,0.01955329,0.02225589,0.02229"
    "977,0.01899122,0.02009433],\"amplitude_offset\":[1.9,1.9]},\"filter\":{\"ra"
    "nge_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.22"
    "3,-0.225,-0.227],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7."
    "85,7.83,7.8,7.78],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15."
    "7,15.8,15.9],\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0."
    "43,0.431,0.431,0.432]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Window "
    "Echo Correction\",\"type\":\"object\",\"properties\":{\"slices\":{\"items\":{\"req"
    "uired\":[\"amplitude\",\"table\"],\"type\":\"object\",\"description\":\"Window "
    "echo correction parameter slice\",\"properties\":{\"table\":{\"items\":{\"item"
    "s\":{\"items\":{\"type\":\"number\",\"description\":\"Table cell (item 0: "
    "amplitude in dB, 1: range in m, 2: "
    "flags)\"},\"type\":\"array\",\"description\":\"Table column (= range "
    "axis)\",\"minItems\":3,\"maxItems\":3},\"type\":\"array\",\"description\":\"Table "
    "row (= amplitude "
    "axis)\",\"minItems\":1},\"type\":\"array\",\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' objects)\",\"minItems\""
    ":1},\"amplitude\":{\"type\":\"number\",\"description\":\"Window echo amplitude "
    "of slice in dB\"}}},\"type\":\"array\"},\"range\":{\"required\":[\"minimum\",\"max"
    "imum\",\"entries\"],\"type\":\"object\",\"description\":\"Range axis of "
    "correction table\",\"properties\":{\"maximum\":{\"maximum\":2.0,\"type\":\"numbe"
    "r\",\"description\":\"Maximum range in "
    "m\",\"minimum\":-2.0},\"entries\":{\"type\":\"integer\",\"description\":\"Number "
    "of range entries\",\"minimum\":1},\"minimum\":{\"maximum\":2.0,\"type\":\"number"
    "\",\"description\":\"Minimum range in m\",\"minimum\":-2.0}}},\"amplitude\":{\"r"
    "equired\":[\"minimum\",\"maximum\",\"entries\"],\"type\":\"object\",\"description\""
    ":\"Amplitude axis of correction "
    "table\",\"properties\":{\"maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " amplitude in "
    "dB\",\"minimum\":0.0},\"entries\":{\"type\":\"integer\",\"description\":\"Number "
    "of amplitude entries\",\"minimum\":1},\"minimum\":{\"type\":\"number\",\"descrip"
    "tion\":\"Minimum amplitude in "
    "dB\",\"minimum\":0.0}}}},\"description\":\"Correction parameters for window "
    "glass echoes\",\"required\":[\"amplitude\",\"range\",\"slices\"]}"
    ,
    /* example: */
    "{\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\""
    ":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}"
    "],\"range\":{\"maximum\":1.5060822940732335,\"entries\":128,\"minimum\":-1.506"
    "0822940732335},\"amplitude\":{\"maximum\":20,\"entries\":128,\"minimum\":2}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
